@@ -1,14 +1,20 @@
+from packaging.version import parse
+import fastai
+
 from .core import *
 from .data import *
 from .augment import *
 from .learner import *
 from .mixup import *
 from ..basics import *
-from ..callback import channelslast, ema, lr_finder, tracker
+from ..callback import ema, lr_finder, tracker
 from ..data.all import *
 from ..losses import *
 from ..metrics import *
 from ..multiloss import *
 from ..optimizer.all import *
 from ..schedulers import *
-from ..utils import *
\ No newline at end of file
+from ..utils import *
+
+if parse(fastai.__version__) < parse('2.7.11'):
+    from ..callback import channelslast
\ No newline at end of file
